<!-- SPDX-License-Identifier: MIT OR Apache-2.0 -->
<!-- SPDX-FileCopyrightText: The Ferrocene Developers -->

# Ferrocene's shared Sphinx resources

This package contains the shared Sphinx resources we rely on for Ferrocene's Sphinx documentation
websites, rather than duplicating them into each site.

🚨 **The contents of this repository are strictly meant for Ferrocene use** 🚨

While this package is public and released under an open source license, breaking changes will
regularly happen, we will provide no support, and third-party pull requests likely won't be
accepted.

The contents of this package are primarily licensed under either the MIT or Apache 2.0 licenses, at
your option. The package also contains files released under different licenses: check the header at
the top of each file, or use [REUSE](https://reuse.software/) to obtain a licensing summary.
